==> client-sdk-1.24.2-sources.jar: com/microsoft/cognitiveservices/speech/speaker/VoiceProfilePhraseResult.java <==
//
// Copyright (c) Microsoft. All rights reserved.
// Licensed under the MIT license. See LICENSE.md file in the project root for full license information.
//
package com.microsoft.cognitiveservices.speech.speaker;

import java.lang.AutoCloseable;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.List;
import com.microsoft.cognitiveservices.speech.util.Contracts;
import com.microsoft.cognitiveservices.speech.PropertyCollection;
import com.microsoft.cognitiveservices.speech.PropertyId;
import com.microsoft.cognitiveservices.speech.RecognitionResult;
import com.microsoft.cognitiveservices.speech.ResultReason;
import com.microsoft.cognitiveservices.speech.util.IntRef;
import com.microsoft.cognitiveservices.speech.util.StringRef;
import com.microsoft.cognitiveservices.speech.util.SafeHandle;
import com.microsoft.cognitiveservices.speech.util.SafeHandleType;

/**
 * Defines result of voice profile activation phrase request.
 */
public final class VoiceProfilePhraseResult implements AutoCloseable
{

    VoiceProfilePhraseResult(long result) {
        this.resultHandle = new SafeHandle(result, SafeHandleType.VoiceProfilePhraseResult);

        StringRef stringVal = new StringRef("");
        Contracts.throwIfFail(getResultId(resultHandle, stringVal));
        this.resultId = stringVal.getValue();
                
        IntRef intVal = new IntRef(0);
        Contracts.throwIfFail(getResultReason(resultHandle, intVal));
        this.reason = ResultReason.values()[(int)intVal.getValue()];

        IntRef propertyHandle = new IntRef(0);
        Contracts.throwIfFail(getPropertyBagFromResult(resultHandle, propertyHandle));
        this.properties = new PropertyCollection(propertyHandle);

        String phrasesString = this.properties.getProperty("speakerrecognition.phrases");
        if (!phrasesString.isEmpty()) {
            this.phrases = Arrays.asList(phrasesString.split("\\|"));
        }

    }

    /**
     * Presents the result identifier.
     * @return The the result identifier.
     */
    public String getResultId() {  
        return this.resultId;
    }

    /**
     * Specifies status of activation phrase result.
     * @return The reason of the result.
     */
    public ResultReason getReason() {
        return this.reason;
    }

    /**
     * Get the activation phrases from the result.
     * @return The activation phrases.
     */
    public List<String> getPhrases() {  
        return this.phrases;
    }

    /**
     * The set of properties exposed in the result.
     * @return The set of properties exposed in the result.
     */
    public PropertyCollection getProperties() {
        return this.properties;
    }

    /**
     * Explicitly frees any external resource attached to the object
     */
    public void close() {
        if (properties != null) {
            properties.close();
            properties = null;
        }
        if (resultHandle != null) {
            resultHandle.close();
            resultHandle = null;
        }        
    }

    /**
     * Returns a String that represents the voice activation phrase result.
     * @return A String that represents the voice activation phrase result.
     */
    @Override
    public String toString() {
        return "ResultId:" + getResultId() +
                " Reason:" + getReason() +
                " Json:" + properties.getProperty(PropertyId.SpeechServiceResponse_JsonResult);
    }

    /*! \cond INTERNAL */
    /**
     * Returns the voice activation phrase result implementation.
     * @return The implementation of the result.
     */
    public SafeHandle getImpl() {
        Contracts.throwIfNull(this.resultHandle, "result");
        return this.resultHandle;
    }
    /*! \endcond */

    private SafeHandle resultHandle = null;
    private PropertyCollection properties = null;
    private String resultId = "";
    private ResultReason reason;
    private List<String> phrases;

    private final native long getResultId(SafeHandle resultHandle, StringRef resultId);
    private final native long getResultReason(SafeHandle resultHandle, IntRef reasonVal);
    private final native long getPropertyBagFromResult(SafeHandle resultHandle, IntRef propertyHandle);

}

==> client-sdk-1.34.0-sources.jar: com/microsoft/cognitiveservices/speech/speaker/VoiceProfilePhraseResult.java <==
//
// Copyright (c) Microsoft. All rights reserved.
// Licensed under the MIT license. See LICENSE.md file in the project root for full license information.
//
package com.microsoft.cognitiveservices.speech.speaker;

import java.lang.AutoCloseable;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.ArrayList;
import java.util.List;
import com.microsoft.cognitiveservices.speech.util.Contracts;
import com.microsoft.cognitiveservices.speech.PropertyCollection;
import com.microsoft.cognitiveservices.speech.PropertyId;
import com.microsoft.cognitiveservices.speech.RecognitionResult;
import com.microsoft.cognitiveservices.speech.ResultReason;
import com.microsoft.cognitiveservices.speech.util.IntRef;
import com.microsoft.cognitiveservices.speech.util.StringRef;
import com.microsoft.cognitiveservices.speech.util.SafeHandle;
import com.microsoft.cognitiveservices.speech.util.SafeHandleType;

/**
 * Defines result of voice profile activation phrase request.
 */
public final class VoiceProfilePhraseResult implements AutoCloseable
{

    VoiceProfilePhraseResult(long result) {
        this.resultHandle = new SafeHandle(result, SafeHandleType.VoiceProfilePhraseResult);

        StringRef stringVal = new StringRef("");
        Contracts.throwIfFail(getResultId(resultHandle, stringVal));
        this.resultId = stringVal.getValue();
                
        IntRef intVal = new IntRef(0);
        Contracts.throwIfFail(getResultReason(resultHandle, intVal));
        this.reason = ResultReason.values()[(int)intVal.getValue()];

        IntRef propertyHandle = new IntRef(0);
        Contracts.throwIfFail(getPropertyBagFromResult(resultHandle, propertyHandle));
        this.properties = new PropertyCollection(propertyHandle);

        String phrasesString = this.properties.getProperty("speakerrecognition.phrases");
        if (!phrasesString.isEmpty()) {
            this.phrases = Arrays.asList(phrasesString.split("\\|"));
        }

    }

    /**
     * Presents the result identifier.
     * @return The result identifier.
     */
    public String getResultId() {  
        return this.resultId;
    }

    /**
     * Specifies status of activation phrase result.
     * @return The reason of the result.
     */
    public ResultReason getReason() {
        return this.reason;
    }

    /**
     * Get the activation phrases from the result.
     * @return The activation phrases.
     */
    public List<String> getPhrases() {  
        return this.phrases;
    }

    /**
     * The set of properties exposed in the result.
     * @return The set of properties exposed in the result.
     */
    public PropertyCollection getProperties() {
        return this.properties;
    }

    /**
     * Explicitly frees any external resource attached to the object
     */
    public void close() {
        if (properties != null) {
            properties.close();
            properties = null;
        }
        if (resultHandle != null) {
            resultHandle.close();
            resultHandle = null;
        }        
    }

    /**
     * Returns a String that represents the voice activation phrase result.
     * @return A String that represents the voice activation phrase result.
     */
    @Override
    public String toString() {
        return "ResultId:" + getResultId() +
                " Reason:" + getReason() +
                " Json:" + properties.getProperty(PropertyId.SpeechServiceResponse_JsonResult);
    }

    /*! \cond INTERNAL */
    /**
     * Returns the voice activation phrase result implementation.
     * @return The implementation of the result.
     */
    public SafeHandle getImpl() {
        Contracts.throwIfNull(this.resultHandle, "result");
        return this.resultHandle;
    }
    /*! \endcond */

    private SafeHandle resultHandle = null;
    private PropertyCollection properties = null;
    private String resultId = "";
    private ResultReason reason;
    private List<String> phrases;

    private final native long getResultId(SafeHandle resultHandle, StringRef resultId);
    private final native long getResultReason(SafeHandle resultHandle, IntRef reasonVal);
    private final native long getPropertyBagFromResult(SafeHandle resultHandle, IntRef propertyHandle);

}
